==> kdelibs-2.2.2.tar.bz2: kdelibs-2.2.2/kdeprint/cups/cupsdconf/cupsdserversecuritypage.h <==
/*
 *  This file is part of the KDE libraries
 *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License version 2 as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public License
 *  along with this library; see the file COPYING.LIB.  If not, write to
 *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 *  Boston, MA 02111-1307, USA.
 **/

#ifndef CUPSDSERVERSECURITYPAGE_H
#define CUPSDSERVERSECURITYPAGE_H

#include "cupsdpage.h"

#include <qlist.h>

class QLineEdit;
class QListView;
class CupsdOption;
class CupsLocation;

class CupsdServerSecurityPage : public CupsdPage
{
	Q_OBJECT;
public:
	CupsdServerSecurityPage(QWidget *parent = 0, const char *name = 0);
	~CupsdServerSecurityPage();

	bool loadConfig(CupsdConf *conf, QString& msg);
	bool saveConfig(CupsdConf *conf, QString& msg);
	void setDefaults();
        void setInfos(CupsdConf*);

protected:
	void updateLocations();

protected slots:
	void addClicked();
	void modifyClicked();
	void removeClicked();

private:
	QLineEdit	*systemgroup_;
	QListView	*locations_;

	CupsdOption	*opt_[1];
	QList<CupsLocation>	loclist_;
};

#endif

==> kdelibs-3.1.3a.tar.bz2: kdelibs-3.1.3a/kdeprint/cups/cupsdconf/cupsdserversecuritypage.h <==
/*
 *  This file is part of the KDE libraries
 *  Copyright (c) 2001 Michael Goffioul <goffioul@imec.be>
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License version 2 as published by the Free Software Foundation.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public License
 *  along with this library; see the file COPYING.LIB.  If not, write to
 *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 *  Boston, MA 02111-1307, USA.
 **/

#ifndef CUPSDSERVERSECURITYPAGE_H
#define CUPSDSERVERSECURITYPAGE_H

#include "cupsdpage.h"

#include <qptrlist.h>

class QLineEdit;
class QListView;
class CupsdOption;
class CupsLocation;

class CupsdServerSecurityPage : public CupsdPage
{
	Q_OBJECT;
public:
	CupsdServerSecurityPage(QWidget *parent = 0, const char *name = 0);
	~CupsdServerSecurityPage();

	bool loadConfig(CupsdConf *conf, QString& msg);
	bool saveConfig(CupsdConf *conf, QString& msg);
	void setDefaults();
        void setInfos(CupsdConf*);

protected:
	void updateLocations();

protected slots:
	void addClicked();
	void modifyClicked();
	void removeClicked();

private:
	QLineEdit	*systemgroup_;
	QListView	*locations_;

	CupsdOption	*opt_[1];
	QPtrList<CupsLocation>	loclist_;
};

#endif
